@@ -3,18 +3,20 @@ from ..scan import *
 from .translator import *
 
 class PandasSubQueryTranslator(SubQueryTranslator):
-  def produce(self, ctx):
-    ctx.request_vars(dict(df=None))
-    self.child_translator.produce(ctx)
+  pass
 
-  def consume(self, ctx):
-    self.v_in = ctx['df']
-    ctx.pop_vars()
+  # def produce(self, ctx):
+  #   ctx.request_vars(dict(df=None))
+  #   self.child_translator.produce(ctx)
 
-    v_out = ctx.new_var(self.op.alias)
-    ctx.add_line("{out} = {df}", out=v_out, df=self.v_in)
-    ctx['df'] = v_out
-    self.parent_translator.consume(ctx)
+  # def consume(self, ctx):
+  #   self.v_in = ctx['df']
+  #   ctx.pop_vars()
+
+  #   v_out = ctx.new_var(self.op.alias)
+  #   ctx.declare(v_out, self.v_in)
+  #   ctx['df'] = v_out
+  #   self.parent_translator.consume(ctx)
 
 
 
@@ -22,9 +24,7 @@ class PandasScanTranslator(ScanTranslator, PandasTranslator):
   def produce(self, ctx):
     v_df = ctx.new_var(self.op.alias)
 
-    ctx.add_line("{df} = db['{tname}']", 
-      df=v_df, 
-      tname=self.op.tablename)
+    ctx.declare(v_df, "db['{n}']".format(n=self.op.tablename))
     ctx["df"] = v_df
 
     if self.child_translator:
